<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/AboutDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <location filename="../src/AlbumView.cpp" line="10"/>
        <source>Browse Album</source>
        <translation>Selaa Albumia</translation>
    </message>
    <message>
        <location filename="../src/AlbumView.cpp" line="12"/>
        <location filename="../src/AlbumView.cpp" line="53"/>
        <source>Album Review</source>
        <translation>Albumin Arvosana</translation>
    </message>
    <message>
        <location filename="../src/AlbumView.cpp" line="101"/>
        <source>Fetching of album details failed!</source>
        <translation>Albumin tietojen hakeminen epäonnistui!</translation>
    </message>
    <message>
        <location filename="../src/AlbumView.cpp" line="134"/>
        <source>Fetching of album details failed: </source>
        <translation>Albumin tietojen hakeminen epäonnistui: </translation>
    </message>
</context>
<context>
    <name>ArtistView</name>
    <message>
        <location filename="../src/artistview.cpp" line="12"/>
        <source>Browse Artist</source>
        <translation>Selaa Artistia</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="14"/>
        <source>Artist Biography</source>
        <translation>Artistin Biographia</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="44"/>
        <source>Biography</source>
        <translation>Biographia</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="81"/>
        <source>Fetching of artist details failed!</source>
        <translation>Artistin tietojen hakeminen epäonnistui!</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="86"/>
        <source>Loading </source>
        <translation>Ladataan</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="106"/>
        <source>Fetching of artist details failed: </source>
        <translation>Artistin tietojen hakeminen epäonnistui: </translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../src/logindialog.cpp" line="21"/>
        <source>QSpot - Login</source>
        <translation>QSpot - Kirjaudu sisään</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="24"/>
        <source>UserID:</source>
        <translation>Tunnus:</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="26"/>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="29"/>
        <location filename="../src/logindialog.cpp" line="180"/>
        <source>Remember UserID and password</source>
        <translation>Muista kirjautumistiedot</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="35"/>
        <source>Low bitrate (96kbps)</source>
        <translation>Vähäinen (96 kt/s)</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="35"/>
        <source>Standard bitrate (160kbps)</source>
        <translation>Normaali (160kt/s)</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="36"/>
        <source>High bitrate (320kbps)</source>
        <translation>Suuri (320kt/s)</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="44"/>
        <source>Preferred bitrate</source>
        <translation>Toivottu siirtonopeus</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="48"/>
        <source>Login</source>
        <translation>Kirjaudu sisään</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="186"/>
        <source>Remember UserID &amp;&amp; Pwd</source>
        <translation>Muista minut</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="18"/>
        <source>QSpot - Playlists</source>
        <translation>QSpot - Soittolistat</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="62"/>
        <location filename="../src/MainWindow.cpp" line="570"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="63"/>
        <location filename="../src/MainWindow.cpp" line="576"/>
        <source>FM Transmitter</source>
        <translation>FM-lähetin</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="64"/>
        <location filename="../src/MainWindow.cpp" line="580"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="179"/>
        <source>About QSpot</source>
        <translation>Tietoa QSpotista</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="181"/>
        <source>QSpot version </source>
        <translation>QSpot-versio</translation>
    </message>
    <message>
        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).

(C) 2011 Andreas Enbacka and The QSpot Team.

Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout.</source>
        <translation type="obsolete">Avoimeen lähdekoodiin, Qt-koodiin perustuva, Spotify-ohjelma N900/Maemo5:lle (perustuu libopenspotify:n).

(C) 2011 Andreas Enbacka ja The QSpot Team.

Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnitteelussa ja ulkoasussa.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="181"/>
        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).

(C) 2011 Andreas Enbacka and The QSpot Team.

Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo) for the Finnish translations.</source>
        <translation>Avoimeen lähdekoodiin, Qt-koodiin perustuva, Spotify-ohjelma N900/Maemo5:lle (perustuu libopenspotify:n).

(C) 2011 Andreas Enbacka ja The QSpot Team.

Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja ulkoasussa sekä Tomille (rantom@tomi) suomenkielelle kääntämisestä.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="406"/>
        <source>Error:</source>
        <translation>Virhe:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="419"/>
        <source>Loading playlists</source>
        <translation>Ladataan soittolistoja</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="436"/>
        <source>Timeout occured while loading playlists!</source>
        <translation>Soittolistoja ladatessa tapahtui aikakatkaisu!</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="464"/>
        <source>tracks</source>
        <translation>kappaletta</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="602"/>
        <source>Searching</source>
        <translation>Etsitään</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="608"/>
        <location filename="../src/MainWindow.cpp" line="623"/>
        <source>Error: </source>
        <translation>Virhe:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="642"/>
        <source>No tracks found!</source>
        <translation>Ei löytynyt kappaleita!</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="656"/>
        <source>Playback paused due to the same account being used somewhere else!</source>
        <translation>Toisto keskeytettiin, koska tunnus on auki toisella koneella!</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="666"/>
        <source>Last.fm error: </source>
        <translation>Last.fm-virhe: </translation>
    </message>
</context>
<context>
    <name>QueueView</name>
    <message>
        <location filename="../src/QueueView.cpp" line="15"/>
        <location filename="../src/QueueView.cpp" line="859"/>
        <location filename="../src/QueueView.cpp" line="868"/>
        <location filename="../src/QueueView.cpp" line="1012"/>
        <source>Now Playing</source>
        <translation>Nyt Soi</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="179"/>
        <source>Play Album</source>
        <translation>Soita Albumi</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="182"/>
        <source>Browse Album</source>
        <translation>Selaa Albumia</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="185"/>
        <source>Browse Artist</source>
        <translation>Selaa Artistia</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="199"/>
        <location filename="../src/QueueView.cpp" line="206"/>
        <source>FM Transmitter</source>
        <translation>FM-lähetin</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="386"/>
        <location filename="../src/QueueView.cpp" line="518"/>
        <location filename="../src/QueueView.cpp" line="803"/>
        <location filename="../src/QueueView.cpp" line="822"/>
        <source>Error starting track playback: </source>
        <translation>Virhe aloitettaessa kappaleen toistoa: </translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="514"/>
        <source>Buffering</source>
        <translation>Puskuroidaan</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="868"/>
        <location filename="../src/QueueView.cpp" line="872"/>
        <location filename="../src/QueueView.cpp" line="1012"/>
        <location filename="../src/QueueView.cpp" line="1045"/>
        <source>Shuffle</source>
        <translation>Sekoitus</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="933"/>
        <source>Loading album tracks</source>
        <translation>Ladataan albumin kappaleita</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="954"/>
        <source>Fetching of album tracks failed: </source>
        <translation>Albumin kaikkien kappaleiden hakeminen epäonnistui: </translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="960"/>
        <source>Failed to load tracks!</source>
        <translation>Ei voitu ladata kappaleita!</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="62"/>
        <source>Landscape</source>
        <translation>Vaaka</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="62"/>
        <source>Portrait</source>
        <translation>Pysty</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="62"/>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="118"/>
        <location filename="../src/SettingsDialog.cpp" line="142"/>
        <source>QSpot - Settings</source>
        <translation>QSpot - Asetukset</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="119"/>
        <source>Max. tracks returned</source>
        <translation>Max. kappaleita tuotu</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="120"/>
        <source>Max. albums returned</source>
        <translation>Max. albumeita tuotu</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="121"/>
        <source>Max. artists returned</source>
        <translation>Max. artisteja tuotu</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="122"/>
        <location filename="../src/SettingsDialog.cpp" line="146"/>
        <source>Search settings</source>
        <translation>Haun asetukset</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="123"/>
        <location filename="../src/SettingsDialog.cpp" line="147"/>
        <source>Buffering settings</source>
        <translation>Puskuroinnin asetukset</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="124"/>
        <source>Min. buffering length (secs)</source>
        <translation>Vähimmäis-puskuroinnin pituus (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="125"/>
        <source>Enable track pre-buffering</source>
        <translation>Salli kappaleen esi-puskurointi</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="126"/>
        <location filename="../src/SettingsDialog.cpp" line="150"/>
        <source>UI Language</source>
        <translation>Käytettävä kieli</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="127"/>
        <location filename="../src/SettingsDialog.cpp" line="151"/>
        <source>Display orientation</source>
        <translation>Näytön suunta</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="128"/>
        <location filename="../src/SettingsDialog.cpp" line="152"/>
        <source>Playlist options</source>
        <translation>Soittolistan valinnat</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="129"/>
        <source>Playlist load timeout (secs)</source>
        <translation>Soittolistan latauksen aikakatkaisu (sekunteina)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="130"/>
        <location filename="../src/SettingsDialog.cpp" line="154"/>
        <source>Pause on headset unplugged</source>
        <translation>Keskeytä toisto kuulokkeiden irrotessa</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="131"/>
        <location filename="../src/SettingsDialog.cpp" line="155"/>
        <source>Scrobbling options</source>
        <translation>Julkistamisasetukset</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="132"/>
        <source>Enable scrobbling to Last.fm</source>
        <translation>Salli kappaleiden julkistaminen Last.fm:lle</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="133"/>
        <location filename="../src/SettingsDialog.cpp" line="157"/>
        <source>Last.fm username</source>
        <translation>Last.fm-tunnus</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="134"/>
        <location filename="../src/SettingsDialog.cpp" line="158"/>
        <source>Last.fm password</source>
        <translation>Last.fm-salasana</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="135"/>
        <location filename="../src/SettingsDialog.cpp" line="159"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="143"/>
        <source>Max. tracks</source>
        <translation>Kappaleita enintään</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="144"/>
        <source>Max. albums</source>
        <translation>Albumeja enintään</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="145"/>
        <source>Max. artists</source>
        <translation>Artisteja enintään</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="148"/>
        <source>Min.buff.length (secs)</source>
        <translation>Vähimmäis-puskurointi (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="149"/>
        <source>Enable track pre-buff.</source>
        <translation>Salli kappaleen esi-puskurointi.</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="153"/>
        <source>Playlist load TO (secs)</source>
        <translation>Soittolistan latauksen aikakatkaisu (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="156"/>
        <source>Enable Last.fm scrobbling</source>
        <translation>Salli Last.fm:lle julkistaminen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="275"/>
        <source>Please restart QSpot for language change to take effect!</source>
        <translation>Käynnistä QSpot uudelleen ottaaksesi käyttöön kieliasetuksen muutokset!</translation>
    </message>
</context>
<context>
    <name>Spotify::Album</name>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="91"/>
        <source>Album</source>
        <translation>Albumi</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="93"/>
        <source>Single</source>
        <translation>Single</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="95"/>
        <source>Compilation</source>
        <translation>Kokoelma</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="97"/>
        <location filename="../src/qspotify_src/album.cpp" line="110"/>
        <source>Appears on</source>
        <translation>Esiintyy </translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="104"/>
        <source>Albums</source>
        <translation>Albumit</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="106"/>
        <source>Singles</source>
        <translation>Singlet</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="108"/>
        <source>Compilations</source>
        <translation>Kokoelmat</translation>
    </message>
</context>
<context>
    <name>TrackView</name>
    <message>
        <location filename="../src/TrackView.cpp" line="54"/>
        <source>Play Album</source>
        <translation>Soita Albumi</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="57"/>
        <source>Browse Album</source>
        <translation>Selaa Albumia</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="60"/>
        <source>Browse Artist</source>
        <translation>Selaa Artistia</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="71"/>
        <source>Sort tracks by</source>
        <translation>Lajittele kappaleet </translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <source>Playlist order</source>
        <translation>Soittolistan järjestyksen mukaan</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Most popular</source>
        <translation>Suosituin </translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Track name (ascending)</source>
        <translation>Kappaleen nimi (nouseva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Track name (descending)</source>
        <translation>Kappaleen nimi (laskeva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Artist name (ascending)</source>
        <translation>Artistin nimi (nouseva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="74"/>
        <location filename="../src/TrackView.cpp" line="77"/>
        <source>Artist name (descending)</source>
        <translation>Artistin nimi (laskeva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="74"/>
        <location filename="../src/TrackView.cpp" line="77"/>
        <source>Album name (ascending)</source>
        <translation>Albumin nimi (nouseva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="74"/>
        <location filename="../src/TrackView.cpp" line="77"/>
        <source>Album name (descending)</source>
        <translation>Albumin nimi (laskeva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Artist, album, track (ascending)</source>
        <translation>Artisti, albumi, kappale (nouseva)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="81"/>
        <location filename="../src/TrackView.cpp" line="190"/>
        <source>FM Transmitter</source>
        <translation>FM-lähetin</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="119"/>
        <source>Loading album tracks</source>
        <translation>Ladataan albumin kappaleita</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="155"/>
        <source>Fetching of album tracks failed: </source>
        <translation>Albumin kappaleiden hakeminen epäonnistui: </translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="161"/>
        <source>Failed to load tracks!</source>
        <translation>Ei voitu ladata kappaleita!</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="273"/>
        <source>Search results: </source>
        <translation>Haun tulokset: </translation>
    </message>
</context>
</TS>
